Learn R Programming

OutliersO3 (version 0.6.3)

Election2005: Election2005 data

Description

A data set for the German 'Bundestag' election of 2005. It includes information about the elections in 2005 and in 2002 separately for each of the 299 constituencies and also demographic and other information about the constituencies themselves.

Usage

data(Election2005)

Arguments

Format

A data frame with 299 observations on 70 variables. The variables of the data set are:

  • 1-4: general information about the constituencies (ID and name of district, Bundesland)

  • 5-40: demographic and economic information

  • 41 - 48: general information about the elections in 2009 and 2005

    • WBerechE: number of eligible voters

    • WE: votes cast

    • UngZE: invalid second votes

    • GulZE: valid second votes

  • 49- 70: results of the five biggest parties in 2009 and 2005 (smaller parties are summarized in the variable Rest). Everything with a 'V' or 'v' at the end is from the election in 2005. 'ze' and 'zv' at the end refer to second votes.

Details

This dataset has been taken from the package mbgraphic of Katrin Grimm.

Examples

Run this code
# NOT RUN {
dim(Election2005)
str(Election2005)
# }

Run the code above in your browser using DataLab